@@ -17,7 +17,7 @@
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 
-"""This module contains a object that represents a Telegram Sticker"""
+"""This module contains a object that represents a Telegram Sticker."""
 
 from telegram import PhotoSize, TelegramObject
 
